@@ -3,7 +3,7 @@ package Complete::Util;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-01-28'; # DATE
 our $DIST = 'Complete-Util'; # DIST
-our $VERSION = '0.610'; # VERSION
+our $VERSION = '0.611'; # VERSION
 
 use 5.010001;
 use strict;
@@ -914,7 +914,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.610 of Complete::Util (from Perl distribution Complete-Util), released on 2020-01-28.
+This document describes version 0.611 of Complete::Util (from Perl distribution Complete-Util), released on 2020-01-28.
 
 =head1 DESCRIPTION
 
@@ -944,7 +944,7 @@ Usage:
 
  answer_has_entries($answer) -> int
 
-Perinci::Sub::To::POD=HASH(0x55d6eeaf0690).
+Check if answer has entries.
 
 It is equivalent to:
 
@@ -958,7 +958,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$answer>* => I<array|hash>
 
-Perinci::Sub::To::POD=HASH(0x55d6eeaf0690).
+Completion answer structure.
+
 
 =back
 
@@ -972,7 +973,7 @@ Usage:
 
  answer_num_entries($answer) -> int
 
-Perinci::Sub::To::POD=HASH(0x55d6eeaf0a68).
+Get the number of entries in an answer.
 
 It is equivalent to:
 
@@ -986,7 +987,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$answer>* => I<array|hash>
 
-Perinci::Sub::To::POD=HASH(0x55d6eeaf0a68).
+Completion answer structure.
+
 
 =back
 
@@ -1000,7 +1002,7 @@ Usage:
 
  arrayify_answer($answer) -> array
 
-Perinci::Sub::To::POD=HASH(0x55d6eeb54a78).
+Make sure we return completion answer in array form.
 
 This is the reverse of C<hashify_answer>. It accepts a hash or an array. If it
 receives a hash, will return its C<words> key.
@@ -1013,7 +1015,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$answer>* => I<array|hash>
 
-Perinci::Sub::To::POD=HASH(0x55d6eeb54a78).
+Completion answer structure.
+
 
 =back
 
@@ -1027,7 +1030,7 @@ Usage:
 
  combine_answers($answers, ...) -> hash
 
-Perinci::Sub::To::POD=HASH(0x55d6eeb55018).
+Given two or more answers, combine them into one.
 
 This function is useful if you want to provide a completion answer that is
 gathered from multiple sources. For example, say you are providing completion
@@ -1050,6 +1053,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$answers>* => I<array[hash|array]>
 
+
 =back
 
 Return value:  (hash)
@@ -1067,7 +1071,7 @@ Usage:
 
  complete_array_elem(%args) -> array
 
-Perinci::Sub::To::POD=HASH(0x55d6eeb55b70).
+Complete from array.
 
 Try to find completion from an array of strings. Will attempt several methods,
 from the cheapest and most discriminating to the most expensive and least
@@ -1126,7 +1130,8 @@ completed unambiguously into C<unmount>.
 
 =item * B<word>* => I<str> (default: "")
 
-Perinci::Sub::To::POD=HASH(0x55d6eeb55b70).
+Word to complete.
+
 
 =back
 
@@ -1140,7 +1145,7 @@ Usage:
 
  complete_comma_sep(%args) -> array
 
-Perinci::Sub::To::POD=HASH(0x55d6eebba320).
+Complete a comma-separated list string.
 
 This function is not exported by default, but exportable.
 
@@ -1154,7 +1159,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<remaining> => I<code>
 
-Perinci::Sub::To::POD=HASH(0x55d6eebba320).
+What elements should remain for completion.
 
 This is a more general mechanism if the C<uniq> option does not suffice. Suppose
 you are offering completion for sorting fields. The elements are field names as
@@ -1201,7 +1206,7 @@ completed unambiguously into C<unmount>.
 
 =item * B<uniq> => I<bool>
 
-Perinci::Sub::To::POD=HASH(0x55d6eebba320).
+Whether list should contain unique elements.
 
 When this option is set to true, if the formed list in the current word already
 contains an element, the element will not be offered again as completion answer.
@@ -1223,7 +1228,8 @@ elements.
 
 =item * B<word>* => I<str> (default: "")
 
-Perinci::Sub::To::POD=HASH(0x55d6eebba320).
+Word to complete.
+
 
 =back
 
@@ -1237,7 +1243,7 @@ Usage:
 
  complete_hash_key(%args) -> array
 
-Perinci::Sub::To::POD=HASH(0x55d6eebb6c78).
+Complete from hash keys.
 
 This function is not exported by default, but exportable.
 
@@ -1253,7 +1259,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<word>* => I<str> (default: "")
 
-Perinci::Sub::To::POD=HASH(0x55d6eebb6c78).
+Word to complete.
+
 
 =back
 
@@ -1267,7 +1274,7 @@ Usage:
 
  hashify_answer($answer, $meta) -> hash
 
-Perinci::Sub::To::POD=HASH(0x55d6eebb7920).
+Make sure we return completion answer in hash form.
 
 This function accepts a hash or an array. If it receives an array, will convert
 the array into `{words=>$ary}' first to make sure the completion answer is in
@@ -1283,11 +1290,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$answer>* => I<array|hash>
 
-Perinci::Sub::To::POD=HASH(0x55d6eebb7920).
+Completion answer structure.
 
 =item * B<$meta> => I<hash>
 
-Perinci::Sub::To::POD=HASH(0x55d6eebb7920).
+Metadata (extra keys) for the hash.
+
 
 =back
 
@@ -1301,7 +1309,7 @@ Usage:
 
  modify_answer(%args) -> undef
 
-Perinci::Sub::To::POD=HASH(0x55d6eeb54b20).
+Modify answer (add prefixE<sol>suffix, etc).
 
 This function is not exported by default, but exportable.
 
@@ -1315,6 +1323,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<suffix> => I<str>
 
+
 =back
 
 Return value:  (undef)
